@@ -1,12 +1,10 @@
 """Low-level AMQP client for Python (fork of amqplib)."""
 # Copyright (C) 2007-2008 Barry Pederson <bp@barryp.org>
-from __future__ import absolute_import, unicode_literals
 
 import re
-
 from collections import namedtuple
 
-__version__ = '2.6.0'
+__version__ = '5.0.1'
 __author__ = 'Barry Pederson'
 __maintainer__ = 'Asif Saif Uddin, Matus Valo'
 __contact__ = 'pyamqp@celeryproject.org'
@@ -29,40 +27,21 @@ del(_temp)
 del(re)
 
 from .basic_message import Message  # noqa
-from .channel import Channel        # noqa
+from .channel import Channel  # noqa
 from .connection import Connection  # noqa
-from .exceptions import (           # noqa
-    AMQPError,
-    ConnectionError,
-    RecoverableConnectionError,
-    IrrecoverableConnectionError,
-    ChannelError,
-    RecoverableChannelError,
-    IrrecoverableChannelError,
-    ConsumerCancelled,
-    ContentTooLarge,
-    NoConsumers,
-    ConnectionForced,
-    InvalidPath,
-    AccessRefused,
-    NotFound,
-    ResourceLocked,
-    PreconditionFailed,
-    FrameError,
-    FrameSyntaxError,
-    InvalidCommand,
-    ChannelNotOpen,
-    UnexpectedFrame,
-    ResourceError,
-    NotAllowed,
-    AMQPNotImplementedError,
-    InternalError,
-    error_for_code,
-)
-from .utils import promise      # noqa
+from .exceptions import (AccessRefused, AMQPError,  # noqa
+                         AMQPNotImplementedError, ChannelError, ChannelNotOpen,
+                         ConnectionError, ConnectionForced, ConsumerCancelled,
+                         ContentTooLarge, FrameError, FrameSyntaxError,
+                         InternalError, InvalidCommand, InvalidPath,
+                         IrrecoverableChannelError,
+                         IrrecoverableConnectionError, NoConsumers, NotAllowed,
+                         NotFound, PreconditionFailed, RecoverableChannelError,
+                         RecoverableConnectionError, ResourceError,
+                         ResourceLocked, UnexpectedFrame, error_for_code)
+from .utils import promise  # noqa
 
-
-__all__ = [
+__all__ = (
     'Connection',
     'Channel',
     'Message',
@@ -93,4 +72,4 @@ __all__ = [
     'AMQPNotImplementedError',
     'InternalError',
     'error_for_code',
-]
+)
