@@ -1,10 +1,10 @@
 """AMQP Channels."""
 # Copyright (C) 2007-2008 Barry Pederson <bp@barryp.org>
-from __future__ import absolute_import, unicode_literals
 
 import logging
 import socket
 from collections import defaultdict
+from queue import Queue
 
 from vine import ensure_promise
 
@@ -13,10 +13,9 @@ from .abstract_channel import AbstractChannel
 from .exceptions import (ChannelError, ConsumerCancelled, MessageNacked,
                          RecoverableChannelError, RecoverableConnectionError,
                          error_for_code)
-from .five import Queue
 from .protocol import queue_declare_ok_t
 
-__all__ = ['Channel']
+__all__ = ('Channel',)
 
 AMQP_LOGGER = logging.getLogger('amqp')
 
@@ -104,7 +103,7 @@ class Channel(AbstractChannel):
 
         AMQP_LOGGER.debug('using channel_id: %s', channel_id)
 
-        super(Channel, self).__init__(connection, channel_id)
+        super().__init__(connection, channel_id)
 
         self.is_open = False
         self.active = True  # Flow control
@@ -209,12 +208,11 @@ class Channel(AbstractChannel):
                 is the ID of the method.
         """
         try:
-            is_closed = (
-                not self.is_open or
-                self.connection is None or
-                self.connection.channels is None
-            )
-            if is_closed:
+            if self.connection is None:
+                return
+            if self.connection.channels is None:
+                return
+            if not self.is_open:
                 return
 
             self.is_closing = True
