@@ -1,12 +1,12 @@
 """Platform compatibility."""
-from __future__ import absolute_import, unicode_literals
 
 import platform
 import re
-import struct
 import sys
 
 # Jython does not have this attribute
+import typing
+
 try:
     from socket import SOL_TCP
 except ImportError:  # pragma: no cover
@@ -16,13 +16,11 @@ except ImportError:  # pragma: no cover
 RE_NUM = re.compile(r'(\d+).+')
 
 
-def _linux_version_to_tuple(s):
-    # type: (str) -> Tuple[int, int, int]
+def _linux_version_to_tuple(s: str) -> typing.Tuple[int, int, int]:
     return tuple(map(_versionatom, s.split('.')[:3]))
 
 
-def _versionatom(s):
-    # type: (str) -> int
+def _versionatom(s: str) -> int:
     if s.isdigit():
         return int(s)
     match = RE_NUM.match(s)
@@ -63,8 +61,8 @@ elif sys.platform.startswith('win'):
 elif sys.platform.startswith('cygwin'):
     KNOWN_TCP_OPTS = {'TCP_NODELAY'}
 
-# illumos does not allow to set the TCP_MAXSEG socket option,
-# even if the Oracle documentation says otherwise.
+    # illumos does not allow to set the TCP_MAXSEG socket option,
+    # even if the Oracle documentation says otherwise.
 elif sys.platform.startswith('sunos'):
     KNOWN_TCP_OPTS.remove('TCP_MAXSEG')
 
@@ -73,32 +71,8 @@ elif sys.platform.startswith('sunos'):
 elif sys.platform.startswith('aix'):
     KNOWN_TCP_OPTS.remove('TCP_MAXSEG')
     KNOWN_TCP_OPTS.remove('TCP_USER_TIMEOUT')
-
-if sys.version_info < (2, 7, 7):  # pragma: no cover
-    import functools
-
-    def _to_bytes_arg(fun):
-        @functools.wraps(fun)
-        def _inner(s, *args, **kwargs):
-            return fun(s.encode(), *args, **kwargs)
-        return _inner
-
-    pack = _to_bytes_arg(struct.pack)
-    pack_into = _to_bytes_arg(struct.pack_into)
-    unpack = _to_bytes_arg(struct.unpack)
-    unpack_from = _to_bytes_arg(struct.unpack_from)
-else:
-    pack = struct.pack
-    pack_into = struct.pack_into
-    unpack = struct.unpack
-    unpack_from = struct.unpack_from
-
-__all__ = [
+__all__ = (
     'LINUX_VERSION',
     'SOL_TCP',
     'KNOWN_TCP_OPTS',
-    'pack',
-    'pack_into',
-    'unpack',
-    'unpack_from',
-]
+)
